@@ -1,8 +1,8 @@
-/* $Id: glibtop_machine.h,v 1.2 2002/08/30 18:58:00 nino Exp $ */
-
-/* Copyright (C) 2002 Nils Nordman
+/* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
+   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
+
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License,
@@ -22,16 +22,33 @@
 #ifndef __GLIBTOP_MACHINE_H__
 #define __GLIBTOP_MACHINE_H__
 
-BEGIN_LIBGTOP_DECLS
+#include <sys/param.h>
+#include <sys/sched.h>
+#include <nlist.h>
+#include <kvm.h>
+#include <time.h>
+#include <sys/user.h>
+#include <sys/types.h>
+#include <sys/proc.h>
+#include <sys/sysctl.h>
 
-typedef struct _glibtop_machine		glibtop_machine;
+#include <fcntl.h>
+
+G_BEGIN_DECLS
+
+typedef struct _glibtop_machine glibtop_machine;
 
 struct _glibtop_machine
 {
-	uid_t uid, euid;		/* Real and effective user id */
-	gid_t gid, egid;		/* Real and effective group id */
+	uid_t uid, euid;
+	gid_t gid, egid;
+
+	/* The kernel descriptor, used by kvm_* calls.  We keep and re-use
+	 * it rather than re-getting it for almost all function
+	 * invocations. */
+	kvm_t *kd;
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
-#endif
+#endif /* __GLIBTOP_MACHINE_H__ */
